@@ -3,7 +3,7 @@
 
 #include <Rcpp.h>
 Rcpp::NumericVector TS_disc(Rcpp::IntegerVector x, 
-                            Rcpp::NumericVector p,
+                            Rcpp::NumericVector Fx,
                             Rcpp::NumericMatrix nm,
                             Rcpp::NumericVector vals
                       );
